.. _userdoc-get-started:

Getting started
===============

ZnTrack is designed to build workflows, track parameters, and keep a record of associated outputs and metrics.
Workflows are defined through Python scripts and human-readable YAML files.
The following sections will guide you through the basic concepts of ZnTrack and how to use it.

.. toctree::
    :maxdepth: 0

    installation
    workflows
    dvc
    project
    api_functions
    api_classes
    making_connections
